@@ -4,7 +4,7 @@ import time
 
 from .exceptions import TimeoutError
 
-LABEL_REUSABLE_CONTAINER = "pytest-docker-tools.reusable-container"
+LABEL_REUSABLE = "pytest-docker-tools.reusable"
 
 
 def wait_for_callable(message, callable, timeout=30):
@@ -34,4 +34,23 @@ def tests_inside_container():
 
 
 def is_reusable_container(container):
-    return container.attrs["Config"]["Labels"].get(LABEL_REUSABLE_CONTAINER) == "True"
+    return container.attrs["Config"]["Labels"].get(LABEL_REUSABLE) == "True"
+
+
+def is_reusable_network(network):
+    return network.attrs["Labels"].get(LABEL_REUSABLE) == "True"
+
+
+def is_reusable_volume(volume):
+    return volume.attrs["Labels"].get(LABEL_REUSABLE) == "True"
+
+
+def set_reusable_labels(kwargs, request):
+    labels = kwargs.setdefault("labels", {})
+
+    labels.update(
+        {
+            "creator": "pytest-docker-tools",
+            LABEL_REUSABLE: str(request.config.option.reuse_containers),
+        }
+    )
